==> haskell-ghc-paths-0.1.0.12-4-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-ghc-paths.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 ghc-paths
version:              0.1.0.12
visibility:           public
id:                   ghc-paths-0.1.0.12-6yfxCcKnGxxC3UhlLpLlce
key:                  ghc-paths-0.1.0.12-6yfxCcKnGxxC3UhlLpLlce
license:              BSD-3-Clause
copyright:            (c) Simon Marlow
maintainer:           Simon Marlow <marlowsd@gmail.com>
author:               Simon Marlow
stability:            stable
synopsis:             Knowledge of GHC'\''s installation directories
description:          Knowledge of GHC'\''s installation directories
category:             Development
abi:                  d9bb9c4c2629f67ab673bca0d72fa5b1
exposed:              True
exposed-modules:      GHC.Paths
import-dirs:          /usr/lib/ghc-8.8.3/site-local/ghc-paths-0.1.0.12
library-dirs:         /usr/lib/ghc-8.8.3/site-local/ghc-paths-0.1.0.12
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.8.3/ghc-paths-0.1.0.12
hs-libraries:         HSghc-paths-0.1.0.12-6yfxCcKnGxxC3UhlLpLlce
depends:              base-4.13.0.0
haddock-interfaces:   /usr/share/doc/haskell-ghc-paths/html/ghc-paths.haddock
haddock-html:         /usr/share/doc/haskell-ghc-paths/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-ghc-paths-0.1.0.12-5-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-ghc-paths.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 ghc-paths
version:              0.1.0.12
visibility:           public
id:                   ghc-paths-0.1.0.12-2Y1vVOYCZeh8LNoHdVhJZB
key:                  ghc-paths-0.1.0.12-2Y1vVOYCZeh8LNoHdVhJZB
license:              BSD-3-Clause
copyright:            (c) Simon Marlow
maintainer:           Simon Marlow <marlowsd@gmail.com>
author:               Simon Marlow
stability:            stable
synopsis:             Knowledge of GHC'\''s installation directories
description:          Knowledge of GHC'\''s installation directories
category:             Development
abi:                  5dac29a1c53b9db1f539386bd6eb4e9b
exposed:              True
exposed-modules:      GHC.Paths
import-dirs:          /usr/lib/ghc-8.10.1/site-local/ghc-paths-0.1.0.12
library-dirs:         /usr/lib/ghc-8.10.1/site-local/ghc-paths-0.1.0.12
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.1/ghc-paths-0.1.0.12
hs-libraries:         HSghc-paths-0.1.0.12-2Y1vVOYCZeh8LNoHdVhJZB
depends:              base-4.14.0.0
haddock-interfaces:   /usr/share/doc/haskell-ghc-paths/html/ghc-paths.haddock
haddock-html:         /usr/share/doc/haskell-ghc-paths/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
